Kivy framework — Kivy v1.0.1-dev documentation

# Kivy framework

Kivy is an open source library for developing multi-touch applications. It is completely cross-platform (Linux/OSX/Win) and released under the terms of the GNU LGPL.

It comes with native support for many multi-touch input devices, a growing library of multi-touch aware widgets, hardware accelerated OpenGL drawing, and an architecture that is designed to let you focus on building custom and highly interactive applications as quickly and easily as possible.

Thanks to Kivy’s pure Python interface, you can take advantage of its highly dynamic nature and use any of the thousands of high quality Python libraries out there. At the same time, performance-critical sections are internally implemented on the C-level to maximize performance.

See http://kivy.org for more information.

`kivy.` `require`(version)

  Require can be used to check the minimum version require to run a Kivy application. For example, you can start your application like this:

      import kivy
      kivy.require('1.0.1')

  If you don’t have a kivy version that fit the minimum required for running the application, it will raise an Exception.

  Note

  The Kivy version is builded like this:

      X.Y.Z[-tag[-tagrevision]]

      X is the Major version
      Y is the Minor version
      Z is the Bugfixes revision

  The tag in Kivy version is optionnal, but may be one of ‘dev’, ‘alpha’, ‘beta’. The tagrevision in Kivy version if the revision of the tag.

  Warning

  You must not ask for a revision with a tag, except -dev. Asking for a ‘dev’ version will just warn the user if the current kivy version is not a dev, it will never launch an exception. You must not ask for a revision with a tagrevision.

`kivy.` `kivy_configure`()

  Call post-configuration of Kivy. This function must be called in case of you create yourself the window.

`kivy.` `kivy_register_post_configuration`(callback)

  Register a function to be call when kivy_configure() will be called.

  Warning

  Internal use only.

`kivy.` `kivy_options`

  Global settings options for kivy

`kivy.` `kivy_base_dir`

  Kivy directory

`kivy.` `kivy_libs_dir`

  Kivy external libraries directory

`kivy.` `kivy_modules_dir`

  Kivy modules directory

`kivy.` `kivy_data_dir`

  Kivy data directory

`kivy.` `kivy_shader_dir`

  Kivy glsl shader directory

`kivy.` `kivy_providers_dir`

  Kivy input provider directory

`kivy.` `kivy_icons_dir`

  Kivy icons config path (don’t remove last ‘’)

`kivy.` `kivy_home_dir`

  Kivy user-home storage directory

`kivy.` `kivy_config_fn`

  Kivy configuration filename

`kivy.` `kivy_usermodules_dir`

  Kivy user modules directory

- Animation
  - Simple animation
  - Sequential animation
  - Parallel animation
- Application
  - Create an application by overidding build()
  - Create an application with kv file
- Event loop management
- Cache manager
- Clock object
- Configuration object
  - Usage of Config object
  - Available configuration tokens
- Event dispatcher
- Factory object
- Gesture recognition
- Kivy language
  - Overview
  - Syntax of a kv file
  - Value expression and reserved keyword
  - Relation between values and properties
  - Graphical instructions
- Asynchronous data loader
- Logger object
- Properties
- Resources management
- Utils
- Vector
- Weak Method